contexttools.is_component_with_key_signature_mark_attached
==========================================================

.. autofunction:: abjad.tools.contexttools.is_component_with_key_signature_mark_attached.is_component_with_key_signature_mark_attached
